/*
 * PROJECT: Indiana University Stiquito Colony Simulator and Control Software
 *
 * (c) Copyright 1996 Jason L. Almeter, Indiana University.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that: (1) source distributions retain this entire copyright
 * notice and comment, and (2) distributions including binaries display
 * the following acknowledgement:  ``This product includes software
 * developed by Indiana University '' in the documentation or other
 * materials provided with the distribution and in all advertising
 * materials mentioning features or use of this software. The
 * name of the University may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * MODULE:
 *	Graphic display of colony/simulation virtual space
 *
 * FILE:
 *	main.c
 *
 * ABSTRACT:
 *	initialize display
 *
 * $Revision: 1.3 $
 * $Date: 1996/01/17 19:12:51 $
 * $Author: jla $
 *
 * HISTORY:
 *
 * $Log: main.c,v $
 * Revision 1.3  1996/01/17  19:12:51  jla
 * Updated Cogyright verbage for release.
 *
 * Revision 1.2  1996/01/15  16:03:05  jla
 * Enrolling in version control.
 *
 *
 */

/* initial code mutated from Mesa/book/simple.c */
#include <stdio.h>

#ifdef SGI

#include <GL/gl.h>
#include <GL/glu.h>
#include <GL/glx.h>
#include <stdlib.h>
#include "aux.h"

#else // SPARC

#include <GL/gl.h>
#include <GL/glu.h>
#include <stdlib.h>
#include "glaux.h"

#endif // SGI

extern sleep(int);



/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: void display()
 *
 * DESCRIPTION: 
 * 	draw the image on the screen
 *
\*--------------------------------------------------------------------------*/

void display()
{
   sim_display();
}

/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: void MySpin()
 *
 * DESCRIPTION: 
 * 	update structures for next anim step
 *
\*--------------------------------------------------------------------------*/


void MySpin()
{
   sim_update();
   sim_display();
}

/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: void MyInit(void)
 *
 * DESCRIPTION: 
 * 	initialize things
 *
\*--------------------------------------------------------------------------*/


void MyInit(void)
{
   GLfloat mat_specular[] = { 1.0, 1.0, 1.0, 1.0 };
   GLfloat mat_shininess[] = { 50.0 };
   GLfloat light_position[] = { -5.0, 3.0, 5.0, 0.0 };
   GLfloat lmodel_ambient[] = { 0.5, 0.5, 0.5, 1.0 };

   glClearColor (0.0, 0.0, 0.0, 0.0);

   makeRasterFont();
   
   glShadeModel(GL_FLAT);/**/
   glDepthFunc(GL_LESS);
   glEnable(GL_DEPTH_TEST);

   /* setup materials (I don't think it's used now) */
   glMaterialfv(GL_FRONT, GL_SPECULAR, mat_specular);
   glMaterialfv(GL_FRONT, GL_SHININESS, mat_shininess);

   /* turn on a light */
   glLightfv(GL_LIGHT0, GL_POSITION, light_position);
   glLightModelfv(GL_LIGHT_MODEL_AMBIENT, lmodel_ambient);

   glEnable(GL_LIGHTING);
   glEnable(GL_LIGHT0);

   /* let us set colors as we go */
   glColorMaterial(GL_FRONT, GL_AMBIENT_AND_DIFFUSE);
   glEnable(GL_COLOR_MATERIAL);
   
   /* init anim variables *****************************/
}

/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: void MyReshape(GLsizei w, GLsizei h)
 *
 * DESCRIPTION: 
 * 	adjust the window
 *
\*--------------------------------------------------------------------------*/


void MyReshape(GLsizei w, GLsizei h)
{
   glViewport(0, 0, w, h);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();

   /* set the camera model *****************************/
   gluPerspective(40.0, (GLfloat) w/(GLfloat) h, 010.0, 210.0);/**/
   glMatrixMode(GL_MODELVIEW);
}

/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: void MyMouseDown(AUX_EVENTREC *event)
 *
 * DESCRIPTION: 
 * quit on a mouse click
 *
\*--------------------------------------------------------------------------*/


void MyMouseDown(AUX_EVENTREC *event)
{
   exit(0);
}

/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: void main(int argc, char** argv)
 *
 * DESCRIPTION: 
 *
\*--------------------------------------------------------------------------*/


void main(int argc, char** argv)
{

#ifdef SGI
   auxInitDisplayMode (AUX_DOUBLE | AUX_RGB | AUX_DEPTH);
#else
   auxInitDisplayMode (AUX_DOUBLE | AUX_RGB | AUX_DEPTH);
#endif /* SGI */

   auxInitPosition (0, 0, 500, 500);
   auxInitWindow (argv[0]);

   MyInit();

   sim_init();

   /* install various handlers */
   auxMouseFunc(AUX_RIGHTBUTTON, AUX_MOUSEDOWN, MyMouseDown);
   auxReshapeFunc(MyReshape);

   /* the animate function */
   auxIdleFunc(MySpin);

   /* this seems to not return */
   auxMainLoop(display);
}


