/*
 * PROJECT: Indiana University Stiquito Colony Simulator and Control Software
 *
 * (c) Copyright 1996 Jason L. Almeter.  All rights reserved.
 *
 * MODULE:
 *	Manual robot command
 *
 * FILE:
 *	robotcmd.c
 *
 * ABSTRACT:
 *	read a robot command from the command line
 *	connect to server and send command
 *	quit
 *
 * $Revision: 1.2 $
 * $Date: 1996/01/15 14:26:07 $
 * $Author: jla $
 *
 * HISTORY:
 *
 * $Log: robotcmd.c,v $
 * Revision 1.2  1996/01/15  14:26:07  jla
 * Enrolling in version control.
 *
 *
 */


#include <stdio.h>
#include <math.h>
#include "tca.h"
#include "motor.h"


/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: main(int argc, char **argv)
 *
 * DESCRIPTION:
 *	interpret command line
 *	connect and send command to server
 *
\*--------------------------------------------------------------------------*/

main(int argc, char **argv)
{
   RobotCmdType cmd;

   if(argc != 3) {
      fprintf(stderr,"usage: %s robot cmd\n", argv[0]);
      exit(-1);
   }

   cmd.robot = atoi(argv[1]);
   
   switch(*argv[2]) {
    case 'f':
    case 'F':
      switch(*(argv[2]+1)) {
       case 0:
	 printf("forward\n");
	 cmd.cmd = CMD_F;
	 break;
       case 'r':
       case 'R':
	 printf("forward right\n");
	 cmd.cmd = CMD_FR;
	 break;
       case 'l':
       case 'L':
	 printf("forward left\n");
	 cmd.cmd = CMD_FL;
	 break;
       default:
	 fprintf(stderr, "eh?: %s\n",argv[2]);
	 exit(-1);
      }
      break;
    case 'r':
    case 'R':
      switch(*(argv[2]+1)) {
       case 0:
	 printf("reverse\n");
	 cmd.cmd = CMD_R;
	 break;
       case 'r':
       case 'R':
	 printf("reverse right\n");
	 cmd.cmd = CMD_RR;
	 break;
       case 'l':
       case 'L':
	 printf("reverse left\n");
	 cmd.cmd = CMD_RL;
	 break;
       default:
	 fprintf(stderr, "eh?: %s\n",argv[2]);
	 exit(-1);
      }
      break;
    case 's':
    case 'S':
      printf("stop\n");
      cmd.cmd = CMD_STOP;
      break;
    case '+':
      printf("led on\n");
      cmd.cmd = CMD_LED_ON;
      break;
    case '-':
      printf("led off\n");
      cmd.cmd = CMD_LED_OFF;
      break;
    default:
      fprintf(stderr, "eh?: %s\n",argv[2]);
      exit(-1);
   }

   printf("send '%s' to %d\n", argv[2], cmd.robot);

   printf("Connect...\n");
   tcaConnectModule("RobotCmd Module", tcaServerMachine());

   tcaWaitUntilReady();

   if(Success != tcaWaitForCommand(RobotCmd, &cmd)) {
      fprintf(stderr, "Failed!!!\n");
   } else {
      printf("Succeeded.\n");
   }

}
