/*
 * PROJECT: Indiana University Stiquito Colony Simulator and Control Software
 *
 * (c) Copyright 1996 Jason L. Almeter, Indiana University.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that: (1) source distributions retain this entire copyright
 * notice and comment, and (2) distributions including binaries display
 * the following acknowledgement:  ``This product includes software
 * developed by Indiana University '' in the documentation or other
 * materials provided with the distribution and in all advertising
 * materials mentioning features or use of this software. The
 * name of the University may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * MODULE:
 *	Utilities
 *
 * FILE:
 *	coords.c
 *
 * ABSTRACT:
 *	initialize and grow coordinate message structures
 *
 * $Revision: 1.3 $
 * $Date: 1996/01/17 19:08:01 $
 * $Author: jla $
 *
 * HISTORY:
 *
 * $Log: coords.c,v $
 * Revision 1.3  1996/01/17  19:08:01  jla
 * Updated Copyright verbage in preparation for release.
 *
 * Revision 1.2  1996/01/15  15:32:54  jla
 * Enrolling in version control.
 *
 *
 */

#include <stdio.h>
#include "coords.h"

void coordInitArray(CoordArrayPtr array)
{
   array->n = 0;
   array->list = 0;
}

/*----------------------------------------------------------------------------*\

  if n will not fit in the array, grow it.  Else do nothing.

  AUTHOR: Jason L. Almeter (jla@cs.indiana.edu)

\*----------------------------------------------------------------------------*/

void coordGrowArray(int n, CoordArrayPtr array)
{
   int i;
   CoordPtr temp;

   if(n < 0) {
      fprintf(stderr,"coordGrowArray: n < 0\n");
      exit(-1);
   }
   
   if(n > array->n) {
      printf("GROWING ARRAY\n");
      if(!(temp = (CoordPtr)malloc((n)*sizeof(CoordType)))) {
	 fprintf(stderr,"coordGrowArray: malloc failed\n");
	 exit(-1);
      }

      for(i=0; i<array->n; i++) {
	 temp[i].x = array->list[i].x;
	 temp[i].y = array->list[i].y;
	 temp[i].theta = array->list[i].theta;
      }
      for(i=array->n; i<n; i++) {
	 temp[i].x = 0.0;
	 temp[i].y = 0.0;
	 temp[i].theta = 0.0;
      }	 
      if(array->list) {
	 free(array->list);
      }
      array->list = temp;
      array->n = n;

   } else {
      /* do nothing */
   }
}
