/*
 * PROJECT: Indiana University Stiquito Colony Simulator and Control Software
 *
 * (c) Copyright 1996 Jason L. Almeter, Indiana University.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms are permitted
 * provided that: (1) source distributions retain this entire copyright
 * notice and comment, and (2) distributions including binaries display
 * the following acknowledgement:  ``This product includes software
 * developed by Indiana University '' in the documentation or other
 * materials provided with the distribution and in all advertising
 * materials mentioning features or use of this software. The
 * name of the University may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * MODULE:
 *	Utilities
 *
 * FILE:
 *	random.c
 *
 * ABSTRACT:
 *	initialize and provide some random numbers
 *
 * $Revision: 1.3 $
 * $Date: 1996/01/17 19:09:00 $
 * $Author: jla $
 *
 * HISTORY:
 *
 * $Log: random.c,v $
 * Revision 1.3  1996/01/17  19:09:00  jla
 * Updated Copyright verbage in preparation for release.
 *
 * Revision 1.2  1996/01/15  15:39:47  jla
 * Enrolling in version control.
 *
 *
 */

/* a few bits to make the simulator less predictable */
#include <stdio.h>
#include <sys/time.h>
#include <math.h>
#include "random.h"

#define PI	3.14159265359


/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: void RandInit(void)
 *
 * DESCRIPTION:
 *	initialize the random number generator
 *
\*--------------------------------------------------------------------------*/

void RandInit(void)
{
   struct timeval tval;

   if(gettimeofday(&tval, 0)) {
      fprintf(stderr, "gettimeofday failed!!\n");
      exit(-1);
   }

   srandom(tval.tv_usec+tval.tv_sec*1021);
}

/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: double RandUnit()
 *
 * DESCRIPTION:
 *	return a random 'double' in [0,1]
 *
\*--------------------------------------------------------------------------*/

double RandUnit()
{
   long t;
   long d;
   double r;

   t = random();
   d = 2147483647;

   r = ((double)t)/((double)d);

   return r;
}

/*--------------------------------------------------------------------------*\
 *
 * FUNCTION: double RandVector(double maxLen, double *x, double *y)
 *
 * DESCRIPTION:
 *	generate a random vector of length [0,maxLen] pointing in a
 *	random direction and stick it in *x,*y
 *
\*--------------------------------------------------------------------------*/


double RandVector(double maxLen, double *x, double *y)
{
   double length,angle;

   angle = 2.0*PI*RandUnit();
   length = maxLen*RandUnit();
   *x = length*cos(angle);
   *y = length*sin(angle);
}

